@@ -8,9 +8,18 @@ class SSLifyMiddleware(object):
 
     .. note::
         This will only take effect if ``settings.DEBUG`` is False.
+
+    .. note::
+        You can also disable this middleware when testing by setting
+        ``settings.SSLIFY_DISABLE`` to True
     """
     def process_request(self, request):
-        if not any((settings.DEBUG, request.is_secure(), request.META.get('HTTP_X_FORWARDED_PROTO', '') == 'https')):
+        # disabled for test mode?
+        if getattr(settings, 'SSLIFY_DISABLE', False):
+            return None
+
+        # proceed as normal
+        if not any((settings.DEBUG, request.is_secure())):
             url = request.build_absolute_uri(request.get_full_path())
             secure_url = url.replace('http://', 'https://')
             return HttpResponsePermanentRedirect(secure_url)
